# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vod/response/response_vod.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from volcengine.base.models.base import base_pb2 as base_dot_base__pb2
from volcengine.vod.models.business import vod_play_pb2 as vod_dot_business_dot_vod__play__pb2
from volcengine.vod.models.business import vod_media_pb2 as vod_dot_business_dot_vod__media__pb2
from volcengine.vod.models.business import vod_upload_pb2 as vod_dot_business_dot_vod__upload__pb2
from volcengine.vod.models.business import vod_workflow_pb2 as vod_dot_business_dot_vod__workflow__pb2
from volcengine.vod.models.business import vod_space_pb2 as vod_dot_business_dot_vod__space__pb2
from volcengine.vod.models.business import vod_cdn_pb2 as vod_dot_business_dot_vod__cdn__pb2
from volcengine.vod.models.business import vod_common_pb2 as vod_dot_business_dot_vod__common__pb2
from volcengine.vod.models.business import vod_smart_strategy_pb2 as vod_dot_business_dot_vod__smart__strategy__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fvod/response/response_vod.proto\x12\x1eVolcengine.Vod.Models.Response\x1a\x0f\x62\x61se/base.proto\x1a\x1bvod/business/vod_play.proto\x1a\x1cvod/business/vod_media.proto\x1a\x1dvod/business/vod_upload.proto\x1a\x1fvod/business/vod_workflow.proto\x1a\x1cvod/business/vod_space.proto\x1a\x1avod/business/vod_cdn.proto\x1a\x1dvod/business/vod_common.proto\x1a%vod/business/vod_smart_strategy.proto\"\xaa\x01\n\x19VodGetAllPlayInfoResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12\x44\n\x06Result\x18\x02 \x01(\x0b\x32\x34.Volcengine.Vod.Models.Business.VodAllPlayInfoResult\"\xa3\x01\n\x16VodGetPlayInfoResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12@\n\x06Result\x18\x02 \x01(\x0b\x32\x30.Volcengine.Vod.Models.Business.VodPlayInfoModel\"\xb7\x01\n\x1eVodGetOriginalPlayInfoResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12L\n\x06Result\x18\x02 \x01(\x0b\x32<.Volcengine.Vod.Models.Business.VodGetOriginalPlayInfoResult\"\xbb\x01\n VodGetPrivateDrmPlayAuthResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12N\n\x06Result\x18\x02 \x01(\x0b\x32>.Volcengine.Vod.Models.Business.VodGetPrivateDrmPlayAuthResult\"\xb7\x01\n\x1eVodGetHlsDecryptionKeyResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12L\n\x06Result\x18\x02 \x01(\x0b\x32<.Volcengine.Vod.Models.Business.VodGetHlsDecryptionKeyResult\"\xd3\x01\n,VodGetPlayInfoWithLiveTimeShiftSceneResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12Z\n\x06Result\x18\x02 \x01(\x0b\x32J.Volcengine.Vod.Models.Business.VodGetPlayInfoWithLiveTimeShiftSceneResult\"\xa0\x01\n\x16VodUploadMediaResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12=\n\x06Result\x18\x02 \x01(\x0b\x32-.Volcengine.Vod.Models.Business.VodCommitData\"\xa7\x01\n\x1eVodQueryUploadTaskInfoResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12<\n\x06Result\x18\x02 \x01(\x0b\x32,.Volcengine.Vod.Models.Business.VodQueryData\"\xa3\x01\n\x14VodUrlUploadResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12\x42\n\x06Result\x18\x02 \x01(\x0b\x32\x32.Volcengine.Vod.Models.Business.VodUrlResponseData\"\xaf\x01\n\x1aVodApplyUploadInfoResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12H\n\x06Result\x18\x02 \x01(\x0b\x32\x38.Volcengine.Vod.Models.Business.VodApplyUploadInfoResult\"\xb1\x01\n\x1bVodCommitUploadInfoResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12I\n\x06Result\x18\x02 \x01(\x0b\x32\x39.Volcengine.Vod.Models.Business.VodCommitUploadInfoResult\"\xa9\x01\n\x18VodGetMediaInfosResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12\x44\n\x06Result\x18\x02 \x01(\x0b\x32\x34.Volcengine.Vod.Models.Business.VodGetMediaInfosData\"e\n\x1aVodUpdateMediaInfoResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\"\xaf\x01\n\x1fVodGetRecommendedPosterResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12\x43\n\x06Result\x18\x02 \x01(\x0b\x32\x33.Volcengine.Vod.Models.Business.VodGetRecPosterData\"n\n#VodUpdateMediaPublishStatusResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\"\xa5\x01\n\x16VodDeleteMediaResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12\x42\n\x06Result\x18\x02 \x01(\x0b\x32\x32.Volcengine.Vod.Models.Business.VodDeleteMediaData\"\xaf\x01\n\x1bVodDeleteTranscodesResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12G\n\x06Result\x18\x02 \x01(\x0b\x32\x37.Volcengine.Vod.Models.Business.VodDeleteTranscodesData\"\xa7\x01\n\x17VodGetMediaListResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12\x43\n\x06Result\x18\x02 \x01(\x0b\x32\x33.Volcengine.Vod.Models.Business.VodGetMediaListData\"\xb5\x01\n\x1eVodGetSubtitleInfoListResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12J\n\x06Result\x18\x02 \x01(\x0b\x32:.Volcengine.Vod.Models.Business.VodGetSubtitleInfoListData\"\xb7\x01\n\x1fVodUpdateSubtitleStatusResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12K\n\x06Result\x18\x02 \x01(\x0b\x32;.Volcengine.Vod.Models.Business.VodUpdateSubtitleStatusData\"h\n\x1dVodUpdateSubtitleInfoResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\"\xb8\x01\n!VodGetAuditFramesForAuditResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12J\n\x06Result\x18\x02 \x01(\x0b\x32:.Volcengine.Vod.Models.Business.VodGetFramesForAuditResult\"\xb5\x01\n\x1eVodGetMLFramesForAuditResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12J\n\x06Result\x18\x02 \x01(\x0b\x32:.Volcengine.Vod.Models.Business.VodGetFramesForAuditResult\"\xbf\x01\n\"VodGetBetterFramesForAuditResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12P\n\x06Result\x18\x02 \x01(\x0b\x32@.Volcengine.Vod.Models.Business.VodGetBetterFramesForAuditResult\"\xb9\x01\n\x1fVodGetAudioInfoForAuditResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12M\n\x06Result\x18\x02 \x01(\x0b\x32=.Volcengine.Vod.Models.Business.VodGetAudioInfoForAuditResult\"\xdb\x01\n0VodGetAutomaticSpeechRecognitionForAuditResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12^\n\x06Result\x18\x02 \x01(\x0b\x32N.Volcengine.Vod.Models.Business.VodGetAutomaticSpeechRecognitionForAuditResult\"\xcd\x01\n)VodGetAudioEventDetectionForAuditResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12W\n\x06Result\x18\x02 \x01(\x0b\x32G.Volcengine.Vod.Models.Business.VodGetAudioEventDetectionForAuditResult\"\xc1\x01\n$VodCreateVideoClassificationResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12P\n\x06Result\x18\x02 \x01(\x0b\x32@.Volcengine.Vod.Models.Business.VodCreateVideoClassificationData\"o\n$VodUpdateVideoClassificationResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\"o\n$VodDeleteVideoClassificationResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\"\xbb\x01\n#VodListVideoClassificationsResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12K\n\x06Result\x18\x02 \x01(\x0b\x32;.Volcengine.Vod.Models.Business.VodVideoClassificationsData\"\xa4\x01\n\x18VodListSnapshotsResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12?\n\x06Result\x18\x02 \x01(\x0b\x32/.Volcengine.Vod.Models.Business.VodSnapshotData\"\xab\x01\n\x18VodStartWorkflowResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12\x46\n\x06Result\x18\x02 \x01(\x0b\x32\x36.Volcengine.Vod.Models.Business.VodStartWorkflowResult\"\xae\x01\n\"VodRetrieveTranscodeResultResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12?\n\x06Result\x18\x02 \x01(\x0b\x32/.Volcengine.Vod.Models.Business.TranscodeResult\"a\n\x16VodCreateSpaceResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\"\x9d\x01\n\x14VodListSpaceResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12<\n\x06Result\x18\x02 \x03(\x0b\x32,.Volcengine.Vod.Models.Business.VodSpaceInfo\"\xa2\x01\n\x19VodGetSpaceDetailResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12<\n\x06Result\x18\x02 \x01(\x0b\x32,.Volcengine.Vod.Models.Business.VodSpaceInfo\"a\n\x16VodUpdateSpaceResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\"m\n\"VodUpdateSpaceUploadConfigResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\"\xa5\x01\n\x15VodListDomainResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12\x43\n\x06Result\x18\x02 \x01(\x0b\x32\x33.Volcengine.Vod.Models.Business.VodDomainConfigInfo\"\xb2\x01\n\x1fVodCreateCdnRefreshTaskResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12\x46\n\x06Result\x18\x02 \x01(\x0b\x32\x36.Volcengine.Vod.Models.Business.VodCreateCdnTaskResult\"\xb2\x01\n\x1fVodCreateCdnPreloadTaskResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12\x46\n\x06Result\x18\x02 \x01(\x0b\x32\x36.Volcengine.Vod.Models.Business.VodCreateCdnTaskResult\"\xa4\x01\n\x17VodListCdnTasksResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12@\n\x06Result\x18\x02 \x01(\x0b\x32\x30.Volcengine.Vod.Models.Business.VodCdnTaskResult\"\xb1\x01\n\x1bVodListCdnAccessLogResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12I\n\x06Result\x18\x02 \x01(\x0b\x32\x39.Volcengine.Vod.Models.Business.VodListCdnAccessLogResult\"\xb7\x01\n\x1eVodListCdnTopAccessUrlResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12L\n\x06Result\x18\x02 \x01(\x0b\x32<.Volcengine.Vod.Models.Business.VodListCdnTopAccessUrlResult\"\xcd\x01\n)VodDescribeVodDomainBandwidthDataResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12W\n\x06Result\x18\x02 \x01(\x0b\x32G.Volcengine.Vod.Models.Business.VodDescribeVodDomainBandwidthDataResult\"\xb7\x01\n\x1eVodCdnStatisticsCommonResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12L\n\x06Result\x18\x02 \x01(\x0b\x32<.Volcengine.Vod.Models.Business.VodCdnStatisticsCommonResult\"\xa2\x01\n\x19VodDescribeIPInfoResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12<\n\x06Result\x18\x02 \x03(\x0b\x32,.Volcengine.Vod.Models.Business.VodCdnIpInfo\"m\n\"VodAddCallbackSubscriptionResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\"f\n\x1bVodSetCallbackEventResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\"\xc9\x01\n\'VodGetSmartStrategyLitePlayInfoResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12U\n\x06Result\x18\x02 \x01(\x0b\x32\x45.Volcengine.Vod.Models.Business.VodGetSmartStrategyLitePlayInfoResultB\xcc\x01\n)com.volcengine.service.vod.model.responseB\x0bVodResponseP\x01ZAgithub.com/volcengine/volc-sdk-golang/service/vod/models/response\xa0\x01\x01\xd8\x01\x01\xca\x02 Volc\\Service\\Vod\\Models\\Response\xe2\x02#Volc\\Service\\Vod\\Models\\GPBMetadatab\x06proto3')



_VODGETALLPLAYINFORESPONSE = DESCRIPTOR.message_types_by_name['VodGetAllPlayInfoResponse']
_VODGETPLAYINFORESPONSE = DESCRIPTOR.message_types_by_name['VodGetPlayInfoResponse']
_VODGETORIGINALPLAYINFORESPONSE = DESCRIPTOR.message_types_by_name['VodGetOriginalPlayInfoResponse']
_VODGETPRIVATEDRMPLAYAUTHRESPONSE = DESCRIPTOR.message_types_by_name['VodGetPrivateDrmPlayAuthResponse']
_VODGETHLSDECRYPTIONKEYRESPONSE = DESCRIPTOR.message_types_by_name['VodGetHlsDecryptionKeyResponse']
_VODGETPLAYINFOWITHLIVETIMESHIFTSCENERESPONSE = DESCRIPTOR.message_types_by_name['VodGetPlayInfoWithLiveTimeShiftSceneResponse']
_VODUPLOADMEDIARESPONSE = DESCRIPTOR.message_types_by_name['VodUploadMediaResponse']
_VODQUERYUPLOADTASKINFORESPONSE = DESCRIPTOR.message_types_by_name['VodQueryUploadTaskInfoResponse']
_VODURLUPLOADRESPONSE = DESCRIPTOR.message_types_by_name['VodUrlUploadResponse']
_VODAPPLYUPLOADINFORESPONSE = DESCRIPTOR.message_types_by_name['VodApplyUploadInfoResponse']
_VODCOMMITUPLOADINFORESPONSE = DESCRIPTOR.message_types_by_name['VodCommitUploadInfoResponse']
_VODGETMEDIAINFOSRESPONSE = DESCRIPTOR.message_types_by_name['VodGetMediaInfosResponse']
_VODUPDATEMEDIAINFORESPONSE = DESCRIPTOR.message_types_by_name['VodUpdateMediaInfoResponse']
_VODGETRECOMMENDEDPOSTERRESPONSE = DESCRIPTOR.message_types_by_name['VodGetRecommendedPosterResponse']
_VODUPDATEMEDIAPUBLISHSTATUSRESPONSE = DESCRIPTOR.message_types_by_name['VodUpdateMediaPublishStatusResponse']
_VODDELETEMEDIARESPONSE = DESCRIPTOR.message_types_by_name['VodDeleteMediaResponse']
_VODDELETETRANSCODESRESPONSE = DESCRIPTOR.message_types_by_name['VodDeleteTranscodesResponse']
_VODGETMEDIALISTRESPONSE = DESCRIPTOR.message_types_by_name['VodGetMediaListResponse']
_VODGETSUBTITLEINFOLISTRESPONSE = DESCRIPTOR.message_types_by_name['VodGetSubtitleInfoListResponse']
_VODUPDATESUBTITLESTATUSRESPONSE = DESCRIPTOR.message_types_by_name['VodUpdateSubtitleStatusResponse']
_VODUPDATESUBTITLEINFORESPONSE = DESCRIPTOR.message_types_by_name['VodUpdateSubtitleInfoResponse']
_VODGETAUDITFRAMESFORAUDITRESPONSE = DESCRIPTOR.message_types_by_name['VodGetAuditFramesForAuditResponse']
_VODGETMLFRAMESFORAUDITRESPONSE = DESCRIPTOR.message_types_by_name['VodGetMLFramesForAuditResponse']
_VODGETBETTERFRAMESFORAUDITRESPONSE = DESCRIPTOR.message_types_by_name['VodGetBetterFramesForAuditResponse']
_VODGETAUDIOINFOFORAUDITRESPONSE = DESCRIPTOR.message_types_by_name['VodGetAudioInfoForAuditResponse']
_VODGETAUTOMATICSPEECHRECOGNITIONFORAUDITRESPONSE = DESCRIPTOR.message_types_by_name['VodGetAutomaticSpeechRecognitionForAuditResponse']
_VODGETAUDIOEVENTDETECTIONFORAUDITRESPONSE = DESCRIPTOR.message_types_by_name['VodGetAudioEventDetectionForAuditResponse']
_VODCREATEVIDEOCLASSIFICATIONRESPONSE = DESCRIPTOR.message_types_by_name['VodCreateVideoClassificationResponse']
_VODUPDATEVIDEOCLASSIFICATIONRESPONSE = DESCRIPTOR.message_types_by_name['VodUpdateVideoClassificationResponse']
_VODDELETEVIDEOCLASSIFICATIONRESPONSE = DESCRIPTOR.message_types_by_name['VodDeleteVideoClassificationResponse']
_VODLISTVIDEOCLASSIFICATIONSRESPONSE = DESCRIPTOR.message_types_by_name['VodListVideoClassificationsResponse']
_VODLISTSNAPSHOTSRESPONSE = DESCRIPTOR.message_types_by_name['VodListSnapshotsResponse']
_VODSTARTWORKFLOWRESPONSE = DESCRIPTOR.message_types_by_name['VodStartWorkflowResponse']
_VODRETRIEVETRANSCODERESULTRESPONSE = DESCRIPTOR.message_types_by_name['VodRetrieveTranscodeResultResponse']
_VODCREATESPACERESPONSE = DESCRIPTOR.message_types_by_name['VodCreateSpaceResponse']
_VODLISTSPACERESPONSE = DESCRIPTOR.message_types_by_name['VodListSpaceResponse']
_VODGETSPACEDETAILRESPONSE = DESCRIPTOR.message_types_by_name['VodGetSpaceDetailResponse']
_VODUPDATESPACERESPONSE = DESCRIPTOR.message_types_by_name['VodUpdateSpaceResponse']
_VODUPDATESPACEUPLOADCONFIGRESPONSE = DESCRIPTOR.message_types_by_name['VodUpdateSpaceUploadConfigResponse']
_VODLISTDOMAINRESPONSE = DESCRIPTOR.message_types_by_name['VodListDomainResponse']
_VODCREATECDNREFRESHTASKRESPONSE = DESCRIPTOR.message_types_by_name['VodCreateCdnRefreshTaskResponse']
_VODCREATECDNPRELOADTASKRESPONSE = DESCRIPTOR.message_types_by_name['VodCreateCdnPreloadTaskResponse']
_VODLISTCDNTASKSRESPONSE = DESCRIPTOR.message_types_by_name['VodListCdnTasksResponse']
_VODLISTCDNACCESSLOGRESPONSE = DESCRIPTOR.message_types_by_name['VodListCdnAccessLogResponse']
_VODLISTCDNTOPACCESSURLRESPONSE = DESCRIPTOR.message_types_by_name['VodListCdnTopAccessUrlResponse']
_VODDESCRIBEVODDOMAINBANDWIDTHDATARESPONSE = DESCRIPTOR.message_types_by_name['VodDescribeVodDomainBandwidthDataResponse']
_VODCDNSTATISTICSCOMMONRESPONSE = DESCRIPTOR.message_types_by_name['VodCdnStatisticsCommonResponse']
_VODDESCRIBEIPINFORESPONSE = DESCRIPTOR.message_types_by_name['VodDescribeIPInfoResponse']
_VODADDCALLBACKSUBSCRIPTIONRESPONSE = DESCRIPTOR.message_types_by_name['VodAddCallbackSubscriptionResponse']
_VODSETCALLBACKEVENTRESPONSE = DESCRIPTOR.message_types_by_name['VodSetCallbackEventResponse']
_VODGETSMARTSTRATEGYLITEPLAYINFORESPONSE = DESCRIPTOR.message_types_by_name['VodGetSmartStrategyLitePlayInfoResponse']
VodGetAllPlayInfoResponse = _reflection.GeneratedProtocolMessageType('VodGetAllPlayInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETALLPLAYINFORESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetAllPlayInfoResponse)
  })
_sym_db.RegisterMessage(VodGetAllPlayInfoResponse)

VodGetPlayInfoResponse = _reflection.GeneratedProtocolMessageType('VodGetPlayInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETPLAYINFORESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetPlayInfoResponse)
  })
_sym_db.RegisterMessage(VodGetPlayInfoResponse)

VodGetOriginalPlayInfoResponse = _reflection.GeneratedProtocolMessageType('VodGetOriginalPlayInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETORIGINALPLAYINFORESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetOriginalPlayInfoResponse)
  })
_sym_db.RegisterMessage(VodGetOriginalPlayInfoResponse)

VodGetPrivateDrmPlayAuthResponse = _reflection.GeneratedProtocolMessageType('VodGetPrivateDrmPlayAuthResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETPRIVATEDRMPLAYAUTHRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetPrivateDrmPlayAuthResponse)
  })
_sym_db.RegisterMessage(VodGetPrivateDrmPlayAuthResponse)

VodGetHlsDecryptionKeyResponse = _reflection.GeneratedProtocolMessageType('VodGetHlsDecryptionKeyResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETHLSDECRYPTIONKEYRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetHlsDecryptionKeyResponse)
  })
_sym_db.RegisterMessage(VodGetHlsDecryptionKeyResponse)

VodGetPlayInfoWithLiveTimeShiftSceneResponse = _reflection.GeneratedProtocolMessageType('VodGetPlayInfoWithLiveTimeShiftSceneResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETPLAYINFOWITHLIVETIMESHIFTSCENERESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetPlayInfoWithLiveTimeShiftSceneResponse)
  })
_sym_db.RegisterMessage(VodGetPlayInfoWithLiveTimeShiftSceneResponse)

VodUploadMediaResponse = _reflection.GeneratedProtocolMessageType('VodUploadMediaResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODUPLOADMEDIARESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodUploadMediaResponse)
  })
_sym_db.RegisterMessage(VodUploadMediaResponse)

VodQueryUploadTaskInfoResponse = _reflection.GeneratedProtocolMessageType('VodQueryUploadTaskInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODQUERYUPLOADTASKINFORESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodQueryUploadTaskInfoResponse)
  })
_sym_db.RegisterMessage(VodQueryUploadTaskInfoResponse)

VodUrlUploadResponse = _reflection.GeneratedProtocolMessageType('VodUrlUploadResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODURLUPLOADRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodUrlUploadResponse)
  })
_sym_db.RegisterMessage(VodUrlUploadResponse)

VodApplyUploadInfoResponse = _reflection.GeneratedProtocolMessageType('VodApplyUploadInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODAPPLYUPLOADINFORESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodApplyUploadInfoResponse)
  })
_sym_db.RegisterMessage(VodApplyUploadInfoResponse)

VodCommitUploadInfoResponse = _reflection.GeneratedProtocolMessageType('VodCommitUploadInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODCOMMITUPLOADINFORESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodCommitUploadInfoResponse)
  })
_sym_db.RegisterMessage(VodCommitUploadInfoResponse)

VodGetMediaInfosResponse = _reflection.GeneratedProtocolMessageType('VodGetMediaInfosResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETMEDIAINFOSRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetMediaInfosResponse)
  })
_sym_db.RegisterMessage(VodGetMediaInfosResponse)

VodUpdateMediaInfoResponse = _reflection.GeneratedProtocolMessageType('VodUpdateMediaInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODUPDATEMEDIAINFORESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodUpdateMediaInfoResponse)
  })
_sym_db.RegisterMessage(VodUpdateMediaInfoResponse)

VodGetRecommendedPosterResponse = _reflection.GeneratedProtocolMessageType('VodGetRecommendedPosterResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETRECOMMENDEDPOSTERRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetRecommendedPosterResponse)
  })
_sym_db.RegisterMessage(VodGetRecommendedPosterResponse)

VodUpdateMediaPublishStatusResponse = _reflection.GeneratedProtocolMessageType('VodUpdateMediaPublishStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODUPDATEMEDIAPUBLISHSTATUSRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodUpdateMediaPublishStatusResponse)
  })
_sym_db.RegisterMessage(VodUpdateMediaPublishStatusResponse)

VodDeleteMediaResponse = _reflection.GeneratedProtocolMessageType('VodDeleteMediaResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODDELETEMEDIARESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodDeleteMediaResponse)
  })
_sym_db.RegisterMessage(VodDeleteMediaResponse)

VodDeleteTranscodesResponse = _reflection.GeneratedProtocolMessageType('VodDeleteTranscodesResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODDELETETRANSCODESRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodDeleteTranscodesResponse)
  })
_sym_db.RegisterMessage(VodDeleteTranscodesResponse)

VodGetMediaListResponse = _reflection.GeneratedProtocolMessageType('VodGetMediaListResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETMEDIALISTRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetMediaListResponse)
  })
_sym_db.RegisterMessage(VodGetMediaListResponse)

VodGetSubtitleInfoListResponse = _reflection.GeneratedProtocolMessageType('VodGetSubtitleInfoListResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETSUBTITLEINFOLISTRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetSubtitleInfoListResponse)
  })
_sym_db.RegisterMessage(VodGetSubtitleInfoListResponse)

VodUpdateSubtitleStatusResponse = _reflection.GeneratedProtocolMessageType('VodUpdateSubtitleStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODUPDATESUBTITLESTATUSRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodUpdateSubtitleStatusResponse)
  })
_sym_db.RegisterMessage(VodUpdateSubtitleStatusResponse)

VodUpdateSubtitleInfoResponse = _reflection.GeneratedProtocolMessageType('VodUpdateSubtitleInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODUPDATESUBTITLEINFORESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodUpdateSubtitleInfoResponse)
  })
_sym_db.RegisterMessage(VodUpdateSubtitleInfoResponse)

VodGetAuditFramesForAuditResponse = _reflection.GeneratedProtocolMessageType('VodGetAuditFramesForAuditResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETAUDITFRAMESFORAUDITRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetAuditFramesForAuditResponse)
  })
_sym_db.RegisterMessage(VodGetAuditFramesForAuditResponse)

VodGetMLFramesForAuditResponse = _reflection.GeneratedProtocolMessageType('VodGetMLFramesForAuditResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETMLFRAMESFORAUDITRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetMLFramesForAuditResponse)
  })
_sym_db.RegisterMessage(VodGetMLFramesForAuditResponse)

VodGetBetterFramesForAuditResponse = _reflection.GeneratedProtocolMessageType('VodGetBetterFramesForAuditResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETBETTERFRAMESFORAUDITRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetBetterFramesForAuditResponse)
  })
_sym_db.RegisterMessage(VodGetBetterFramesForAuditResponse)

VodGetAudioInfoForAuditResponse = _reflection.GeneratedProtocolMessageType('VodGetAudioInfoForAuditResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETAUDIOINFOFORAUDITRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetAudioInfoForAuditResponse)
  })
_sym_db.RegisterMessage(VodGetAudioInfoForAuditResponse)

VodGetAutomaticSpeechRecognitionForAuditResponse = _reflection.GeneratedProtocolMessageType('VodGetAutomaticSpeechRecognitionForAuditResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETAUTOMATICSPEECHRECOGNITIONFORAUDITRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetAutomaticSpeechRecognitionForAuditResponse)
  })
_sym_db.RegisterMessage(VodGetAutomaticSpeechRecognitionForAuditResponse)

VodGetAudioEventDetectionForAuditResponse = _reflection.GeneratedProtocolMessageType('VodGetAudioEventDetectionForAuditResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETAUDIOEVENTDETECTIONFORAUDITRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetAudioEventDetectionForAuditResponse)
  })
_sym_db.RegisterMessage(VodGetAudioEventDetectionForAuditResponse)

VodCreateVideoClassificationResponse = _reflection.GeneratedProtocolMessageType('VodCreateVideoClassificationResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODCREATEVIDEOCLASSIFICATIONRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodCreateVideoClassificationResponse)
  })
_sym_db.RegisterMessage(VodCreateVideoClassificationResponse)

VodUpdateVideoClassificationResponse = _reflection.GeneratedProtocolMessageType('VodUpdateVideoClassificationResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODUPDATEVIDEOCLASSIFICATIONRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodUpdateVideoClassificationResponse)
  })
_sym_db.RegisterMessage(VodUpdateVideoClassificationResponse)

VodDeleteVideoClassificationResponse = _reflection.GeneratedProtocolMessageType('VodDeleteVideoClassificationResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODDELETEVIDEOCLASSIFICATIONRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodDeleteVideoClassificationResponse)
  })
_sym_db.RegisterMessage(VodDeleteVideoClassificationResponse)

VodListVideoClassificationsResponse = _reflection.GeneratedProtocolMessageType('VodListVideoClassificationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODLISTVIDEOCLASSIFICATIONSRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodListVideoClassificationsResponse)
  })
_sym_db.RegisterMessage(VodListVideoClassificationsResponse)

VodListSnapshotsResponse = _reflection.GeneratedProtocolMessageType('VodListSnapshotsResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODLISTSNAPSHOTSRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodListSnapshotsResponse)
  })
_sym_db.RegisterMessage(VodListSnapshotsResponse)

VodStartWorkflowResponse = _reflection.GeneratedProtocolMessageType('VodStartWorkflowResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODSTARTWORKFLOWRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodStartWorkflowResponse)
  })
_sym_db.RegisterMessage(VodStartWorkflowResponse)

VodRetrieveTranscodeResultResponse = _reflection.GeneratedProtocolMessageType('VodRetrieveTranscodeResultResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODRETRIEVETRANSCODERESULTRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodRetrieveTranscodeResultResponse)
  })
_sym_db.RegisterMessage(VodRetrieveTranscodeResultResponse)

VodCreateSpaceResponse = _reflection.GeneratedProtocolMessageType('VodCreateSpaceResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODCREATESPACERESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodCreateSpaceResponse)
  })
_sym_db.RegisterMessage(VodCreateSpaceResponse)

VodListSpaceResponse = _reflection.GeneratedProtocolMessageType('VodListSpaceResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODLISTSPACERESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodListSpaceResponse)
  })
_sym_db.RegisterMessage(VodListSpaceResponse)

VodGetSpaceDetailResponse = _reflection.GeneratedProtocolMessageType('VodGetSpaceDetailResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETSPACEDETAILRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetSpaceDetailResponse)
  })
_sym_db.RegisterMessage(VodGetSpaceDetailResponse)

VodUpdateSpaceResponse = _reflection.GeneratedProtocolMessageType('VodUpdateSpaceResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODUPDATESPACERESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodUpdateSpaceResponse)
  })
_sym_db.RegisterMessage(VodUpdateSpaceResponse)

VodUpdateSpaceUploadConfigResponse = _reflection.GeneratedProtocolMessageType('VodUpdateSpaceUploadConfigResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODUPDATESPACEUPLOADCONFIGRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodUpdateSpaceUploadConfigResponse)
  })
_sym_db.RegisterMessage(VodUpdateSpaceUploadConfigResponse)

VodListDomainResponse = _reflection.GeneratedProtocolMessageType('VodListDomainResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODLISTDOMAINRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodListDomainResponse)
  })
_sym_db.RegisterMessage(VodListDomainResponse)

VodCreateCdnRefreshTaskResponse = _reflection.GeneratedProtocolMessageType('VodCreateCdnRefreshTaskResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODCREATECDNREFRESHTASKRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodCreateCdnRefreshTaskResponse)
  })
_sym_db.RegisterMessage(VodCreateCdnRefreshTaskResponse)

VodCreateCdnPreloadTaskResponse = _reflection.GeneratedProtocolMessageType('VodCreateCdnPreloadTaskResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODCREATECDNPRELOADTASKRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodCreateCdnPreloadTaskResponse)
  })
_sym_db.RegisterMessage(VodCreateCdnPreloadTaskResponse)

VodListCdnTasksResponse = _reflection.GeneratedProtocolMessageType('VodListCdnTasksResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODLISTCDNTASKSRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodListCdnTasksResponse)
  })
_sym_db.RegisterMessage(VodListCdnTasksResponse)

VodListCdnAccessLogResponse = _reflection.GeneratedProtocolMessageType('VodListCdnAccessLogResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODLISTCDNACCESSLOGRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodListCdnAccessLogResponse)
  })
_sym_db.RegisterMessage(VodListCdnAccessLogResponse)

VodListCdnTopAccessUrlResponse = _reflection.GeneratedProtocolMessageType('VodListCdnTopAccessUrlResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODLISTCDNTOPACCESSURLRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodListCdnTopAccessUrlResponse)
  })
_sym_db.RegisterMessage(VodListCdnTopAccessUrlResponse)

VodDescribeVodDomainBandwidthDataResponse = _reflection.GeneratedProtocolMessageType('VodDescribeVodDomainBandwidthDataResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODDESCRIBEVODDOMAINBANDWIDTHDATARESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodDescribeVodDomainBandwidthDataResponse)
  })
_sym_db.RegisterMessage(VodDescribeVodDomainBandwidthDataResponse)

VodCdnStatisticsCommonResponse = _reflection.GeneratedProtocolMessageType('VodCdnStatisticsCommonResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODCDNSTATISTICSCOMMONRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodCdnStatisticsCommonResponse)
  })
_sym_db.RegisterMessage(VodCdnStatisticsCommonResponse)

VodDescribeIPInfoResponse = _reflection.GeneratedProtocolMessageType('VodDescribeIPInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODDESCRIBEIPINFORESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodDescribeIPInfoResponse)
  })
_sym_db.RegisterMessage(VodDescribeIPInfoResponse)

VodAddCallbackSubscriptionResponse = _reflection.GeneratedProtocolMessageType('VodAddCallbackSubscriptionResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODADDCALLBACKSUBSCRIPTIONRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodAddCallbackSubscriptionResponse)
  })
_sym_db.RegisterMessage(VodAddCallbackSubscriptionResponse)

VodSetCallbackEventResponse = _reflection.GeneratedProtocolMessageType('VodSetCallbackEventResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODSETCALLBACKEVENTRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodSetCallbackEventResponse)
  })
_sym_db.RegisterMessage(VodSetCallbackEventResponse)

VodGetSmartStrategyLitePlayInfoResponse = _reflection.GeneratedProtocolMessageType('VodGetSmartStrategyLitePlayInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETSMARTSTRATEGYLITEPLAYINFORESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetSmartStrategyLitePlayInfoResponse)
  })
_sym_db.RegisterMessage(VodGetSmartStrategyLitePlayInfoResponse)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)com.volcengine.service.vod.model.responseB\013VodResponseP\001ZAgithub.com/volcengine/volc-sdk-golang/service/vod/models/response\240\001\001\330\001\001\312\002 Volc\\Service\\Vod\\Models\\Response\342\002#Volc\\Service\\Vod\\Models\\GPBMetadata'
  _VODGETALLPLAYINFORESPONSE._serialized_start=336
  _VODGETALLPLAYINFORESPONSE._serialized_end=506
  _VODGETPLAYINFORESPONSE._serialized_start=509
  _VODGETPLAYINFORESPONSE._serialized_end=672
  _VODGETORIGINALPLAYINFORESPONSE._serialized_start=675
  _VODGETORIGINALPLAYINFORESPONSE._serialized_end=858
  _VODGETPRIVATEDRMPLAYAUTHRESPONSE._serialized_start=861
  _VODGETPRIVATEDRMPLAYAUTHRESPONSE._serialized_end=1048
  _VODGETHLSDECRYPTIONKEYRESPONSE._serialized_start=1051
  _VODGETHLSDECRYPTIONKEYRESPONSE._serialized_end=1234
  _VODGETPLAYINFOWITHLIVETIMESHIFTSCENERESPONSE._serialized_start=1237
  _VODGETPLAYINFOWITHLIVETIMESHIFTSCENERESPONSE._serialized_end=1448
  _VODUPLOADMEDIARESPONSE._serialized_start=1451
  _VODUPLOADMEDIARESPONSE._serialized_end=1611
  _VODQUERYUPLOADTASKINFORESPONSE._serialized_start=1614
  _VODQUERYUPLOADTASKINFORESPONSE._serialized_end=1781
  _VODURLUPLOADRESPONSE._serialized_start=1784
  _VODURLUPLOADRESPONSE._serialized_end=1947
  _VODAPPLYUPLOADINFORESPONSE._serialized_start=1950
  _VODAPPLYUPLOADINFORESPONSE._serialized_end=2125
  _VODCOMMITUPLOADINFORESPONSE._serialized_start=2128
  _VODCOMMITUPLOADINFORESPONSE._serialized_end=2305
  _VODGETMEDIAINFOSRESPONSE._serialized_start=2308
  _VODGETMEDIAINFOSRESPONSE._serialized_end=2477
  _VODUPDATEMEDIAINFORESPONSE._serialized_start=2479
  _VODUPDATEMEDIAINFORESPONSE._serialized_end=2580
  _VODGETRECOMMENDEDPOSTERRESPONSE._serialized_start=2583
  _VODGETRECOMMENDEDPOSTERRESPONSE._serialized_end=2758
  _VODUPDATEMEDIAPUBLISHSTATUSRESPONSE._serialized_start=2760
  _VODUPDATEMEDIAPUBLISHSTATUSRESPONSE._serialized_end=2870
  _VODDELETEMEDIARESPONSE._serialized_start=2873
  _VODDELETEMEDIARESPONSE._serialized_end=3038
  _VODDELETETRANSCODESRESPONSE._serialized_start=3041
  _VODDELETETRANSCODESRESPONSE._serialized_end=3216
  _VODGETMEDIALISTRESPONSE._serialized_start=3219
  _VODGETMEDIALISTRESPONSE._serialized_end=3386
  _VODGETSUBTITLEINFOLISTRESPONSE._serialized_start=3389
  _VODGETSUBTITLEINFOLISTRESPONSE._serialized_end=3570
  _VODUPDATESUBTITLESTATUSRESPONSE._serialized_start=3573
  _VODUPDATESUBTITLESTATUSRESPONSE._serialized_end=3756
  _VODUPDATESUBTITLEINFORESPONSE._serialized_start=3758
  _VODUPDATESUBTITLEINFORESPONSE._serialized_end=3862
  _VODGETAUDITFRAMESFORAUDITRESPONSE._serialized_start=3865
  _VODGETAUDITFRAMESFORAUDITRESPONSE._serialized_end=4049
  _VODGETMLFRAMESFORAUDITRESPONSE._serialized_start=4052
  _VODGETMLFRAMESFORAUDITRESPONSE._serialized_end=4233
  _VODGETBETTERFRAMESFORAUDITRESPONSE._serialized_start=4236
  _VODGETBETTERFRAMESFORAUDITRESPONSE._serialized_end=4427
  _VODGETAUDIOINFOFORAUDITRESPONSE._serialized_start=4430
  _VODGETAUDIOINFOFORAUDITRESPONSE._serialized_end=4615
  _VODGETAUTOMATICSPEECHRECOGNITIONFORAUDITRESPONSE._serialized_start=4618
  _VODGETAUTOMATICSPEECHRECOGNITIONFORAUDITRESPONSE._serialized_end=4837
  _VODGETAUDIOEVENTDETECTIONFORAUDITRESPONSE._serialized_start=4840
  _VODGETAUDIOEVENTDETECTIONFORAUDITRESPONSE._serialized_end=5045
  _VODCREATEVIDEOCLASSIFICATIONRESPONSE._serialized_start=5048
  _VODCREATEVIDEOCLASSIFICATIONRESPONSE._serialized_end=5241
  _VODUPDATEVIDEOCLASSIFICATIONRESPONSE._serialized_start=5243
  _VODUPDATEVIDEOCLASSIFICATIONRESPONSE._serialized_end=5354
  _VODDELETEVIDEOCLASSIFICATIONRESPONSE._serialized_start=5356
  _VODDELETEVIDEOCLASSIFICATIONRESPONSE._serialized_end=5467
  _VODLISTVIDEOCLASSIFICATIONSRESPONSE._serialized_start=5470
  _VODLISTVIDEOCLASSIFICATIONSRESPONSE._serialized_end=5657
  _VODLISTSNAPSHOTSRESPONSE._serialized_start=5660
  _VODLISTSNAPSHOTSRESPONSE._serialized_end=5824
  _VODSTARTWORKFLOWRESPONSE._serialized_start=5827
  _VODSTARTWORKFLOWRESPONSE._serialized_end=5998
  _VODRETRIEVETRANSCODERESULTRESPONSE._serialized_start=6001
  _VODRETRIEVETRANSCODERESULTRESPONSE._serialized_end=6175
  _VODCREATESPACERESPONSE._serialized_start=6177
  _VODCREATESPACERESPONSE._serialized_end=6274
  _VODLISTSPACERESPONSE._serialized_start=6277
  _VODLISTSPACERESPONSE._serialized_end=6434
  _VODGETSPACEDETAILRESPONSE._serialized_start=6437
  _VODGETSPACEDETAILRESPONSE._serialized_end=6599
  _VODUPDATESPACERESPONSE._serialized_start=6601
  _VODUPDATESPACERESPONSE._serialized_end=6698
  _VODUPDATESPACEUPLOADCONFIGRESPONSE._serialized_start=6700
  _VODUPDATESPACEUPLOADCONFIGRESPONSE._serialized_end=6809
  _VODLISTDOMAINRESPONSE._serialized_start=6812
  _VODLISTDOMAINRESPONSE._serialized_end=6977
  _VODCREATECDNREFRESHTASKRESPONSE._serialized_start=6980
  _VODCREATECDNREFRESHTASKRESPONSE._serialized_end=7158
  _VODCREATECDNPRELOADTASKRESPONSE._serialized_start=7161
  _VODCREATECDNPRELOADTASKRESPONSE._serialized_end=7339
  _VODLISTCDNTASKSRESPONSE._serialized_start=7342
  _VODLISTCDNTASKSRESPONSE._serialized_end=7506
  _VODLISTCDNACCESSLOGRESPONSE._serialized_start=7509
  _VODLISTCDNACCESSLOGRESPONSE._serialized_end=7686
  _VODLISTCDNTOPACCESSURLRESPONSE._serialized_start=7689
  _VODLISTCDNTOPACCESSURLRESPONSE._serialized_end=7872
  _VODDESCRIBEVODDOMAINBANDWIDTHDATARESPONSE._serialized_start=7875
  _VODDESCRIBEVODDOMAINBANDWIDTHDATARESPONSE._serialized_end=8080
  _VODCDNSTATISTICSCOMMONRESPONSE._serialized_start=8083
  _VODCDNSTATISTICSCOMMONRESPONSE._serialized_end=8266
  _VODDESCRIBEIPINFORESPONSE._serialized_start=8269
  _VODDESCRIBEIPINFORESPONSE._serialized_end=8431
  _VODADDCALLBACKSUBSCRIPTIONRESPONSE._serialized_start=8433
  _VODADDCALLBACKSUBSCRIPTIONRESPONSE._serialized_end=8542
  _VODSETCALLBACKEVENTRESPONSE._serialized_start=8544
  _VODSETCALLBACKEVENTRESPONSE._serialized_end=8646
  _VODGETSMARTSTRATEGYLITEPLAYINFORESPONSE._serialized_start=8649
  _VODGETSMARTSTRATEGYLITEPLAYINFORESPONSE._serialized_end=8850
# @@protoc_insertion_point(module_scope)



# coding:utf-8
from __future__ import print_function

import json

from volcengine.util.Functions import Function
from volcengine.vod.VodService import VodService
from volcengine.const.Const import *
from volcengine.vod.models.request.request_vod_pb2 import VodUploadMaterialRequest

if __name__ == '__main__':
    vod_service = VodService()

    # call below method if you dont set ak and sk in $HOME/.vcloud/config
    vod_service.set_ak('your ak')
    vod_service.set_sk('your sk')

    space_name = 'your space name'
    file_path = 'your file path'

    get_meta_function = Function.get_meta_func()
    snapshot_function = Function.get_snapshot_func(2.3)
    add_option_function = Function.get_add_material_option_info_func(title='素材测试视频', tags='test',
                                                                     description='素材测试，视频文件',
                                                                     category=CATEGORY_VIDEO, record_type=2,
                                                                     format_input='MP4')

    try:
        req = VodUploadMaterialRequest()
        req.FileType = FILE_TYPE_MEDIA
        req.SpaceName = space_name
        req.FilePath = file_path
        req.Functions = json.dumps([get_meta_function, snapshot_function, add_option_function])
        req.CallbackArgs = ''

        resp = vod_service.upload_material(req)
    except Exception:
        raise
    else:
        print(resp)
        if resp.ResponseMetadata.Error.Code == '':
            print(resp.Result.Data)
            print(resp.Result.Data.Mid)
            print(resp.Result.Data.PosterUri)
            print(resp.Result.Data.SourceInfo.Height)
            print(resp.Result.Data.SourceInfo.Width)
        else:
            print(resp.ResponseMetadata.Error)
            print(resp.ResponseMetadata.RequestId)

if __name__ == '__main__':
    vod_service = VodService()

    # call below method if you dont set ak and sk in $HOME/.vcloud/config
    vod_service.set_ak('your ak')
    vod_service.set_sk('your sk')

    space_name = 'your space name'
    file_path = 'your file path'

    get_meta_function = Function.get_meta_func()
    snapshot_function = Function.get_snapshot_func(0)
    add_option_function = Function.get_add_material_option_info_func(title='素材测试图片', tags='test',
                                                                     description='素材测试，图片文件',
                                                                     category=CATEGORY_IMAGE, record_type=2,
                                                                     format_input='jpg')

    try:
        req = VodUploadMaterialRequest()
        req.FileType = FILE_TYPE_IMAGE
        req.SpaceName = space_name
        req.FilePath = file_path
        req.Functions = json.dumps([get_meta_function, snapshot_function, add_option_function])
        req.CallbackArgs = ''
        req.FileName = ''

        resp = vod_service.upload_material(req)
    except Exception:
        raise
    else:
        print(resp)
        if resp.ResponseMetadata.Error.Code == '':
            print(resp.Result.Data)
            print(resp.Result.Data.Mid)
            print(resp.Result.Data.PosterUri)
            print(resp.Result.Data.SourceInfo.Height)
            print(resp.Result.Data.SourceInfo.Width)
        else:
            print(resp.ResponseMetadata.Error)
            print(resp.ResponseMetadata.RequestId)

if __name__ == '__main__':
    vod_service = VodService()

    # call below method if you dont set ak and sk in $HOME/.vcloud/config
    vod_service.set_ak('your ak')
    vod_service.set_sk('your sk')

    space_name = 'your space name'
    file_path = 'your file path'

    get_meta_function = Function.get_meta_func()
    add_option_function = Function.get_add_material_option_info_func(title='素材测试字幕', tags='test',
                                                                     description='素材测试，字幕文件',
                                                                     category=CATEGORY_FONT, record_type=2,
                                                                     format_input='vtt')

    try:
        req = VodUploadMaterialRequest()
        req.FileType = FILE_TYPE_OBJECT
        req.SpaceName = space_name
        req.FilePath = file_path
        req.Functions = json.dumps([get_meta_function, add_option_function])
        req.CallbackArgs = ''
        req.FileName = ''

        resp = vod_service.upload_material(req)
    except Exception:
        raise
    else:
        print(resp)
        if resp.ResponseMetadata.Error.Code == '':
            print(resp.Result.Data)
            print(resp.Result.Data.Mid)
        else:
            print(resp.ResponseMetadata.Error)
            print(resp.ResponseMetadata.RequestId)



# coding:utf-8

from setuptools import setup, find_packages
from volcengine import VERSION

setup(
    name="volcengine",
    version=VERSION,
    keywords=("pip", "volcengine", "volc-sdk-python"),
    description="The Volcengine SDK for Python",
    license="MIT Licence",

    url="https://github.com/Volcengine/volc-sdk-python",
    author="Volcengine SDK",

    packages=find_packages(),
    include_package_data=True,
    platforms="any",
    install_requires=["requests", "retry", "pytz", "pycryptodome", "protobuf", "google", "six", "pycrypto"]
)



import json
import threading
import redo

from volcengine.ApiInfo import ApiInfo
from volcengine.Credentials import Credentials
from volcengine.base.Service import Service
from volcengine.ServiceInfo import ServiceInfo
from requests import exceptions


class ImageRegistryService(Service):
    _instance_lock = threading.Lock()

    def __new__(cls, *args, **kwargs):
        if not hasattr(ImageRegistryService, "_instance"):
            with ImageRegistryService._instance_lock:
                if not hasattr(ImageRegistryService, "_instance"):
                    ImageRegistryService._instance = object.__new__(cls)
        return ImageRegistryService._instance

    def __init__(self):
        self.service_info = ImageRegistryService.get_service_info()
        self.api_info = ImageRegistryService.get_api_info()
        super(ImageRegistryService, self).__init__(
            self.service_info, self.api_info)

    @staticmethod
    def get_service_info():
        service_info = ServiceInfo("open.volcengineapi.com", {'Accept': 'application/json'},
                                   Credentials('', '', 'cr', 'cn-north-1'), 5, 5)
        return service_info

    @staticmethod
    def get_api_info():
        api_info = {
            "DeleteNamespaceBasic": ApiInfo(
                "POST", "/", {"Action": "DeleteNamespaceBasic", "Version": "2021-03-03"}, {}, {}),
            "CreateNamespaceBasic": ApiInfo(
                "POST", "/", {"Action": "CreateNamespaceBasic", "Version": "2021-03-03"}, {}, {}),
            "ValidateNamespaceBasic": ApiInfo(
                "POST", "/", {"Action": "ValidateNamespaceBasic", "Version": "2021-03-03"}, {}, {}),
            "GetNamespaceBasic": ApiInfo(
                "POST", "/", {"Action": "GetNamespaceBasic", "Version": "2021-03-03"}, {}, {}),
            "ListNamespacesBasic": ApiInfo(
                "POST", "/", {"Action": "ListNamespacesBasic", "Version": "2021-03-03"}, {}, {}),
            "ValidateRepositoryBasic": ApiInfo(
                "POST", "/", {"Action": "ValidateRepositoryBasic", "Version": "2021-03-03"}, {}, {}),
            "DeleteRepositoryBasic": ApiInfo(
                "POST", "/", {"Action": "DeleteRepositoryBasic", "Version": "2021-03-03"}, {}, {}),
            "CreateRepositoryBasic": ApiInfo(
                "POST", "/", {"Action": "CreateRepositoryBasic", "Version": "2021-03-03"}, {}, {}),
            "UpdateRepositoryBasic": ApiInfo(
                "POST", "/", {"Action": "UpdateRepositoryBasic", "Version": "2021-03-03"}, {}, {}),
            "GetRepositoryBasic": ApiInfo(
                "POST", "/", {"Action": "GetRepositoryBasic", "Version": "2021-03-03"}, {}, {}),
            "ListRepositoriesBasic": ApiInfo(
                "POST", "/", {"Action": "ListRepositoriesBasic", "Version": "2021-03-03"}, {}, {}),
            "DeleteTagBasic": ApiInfo(
                "POST", "/", {"Action": "DeleteTagBasic", "Version": "2021-03-03"}, {}, {}),
            "ListTagsBasic": ApiInfo(
                "POST", "/", {"Action": "ListTagsBasic", "Version": "2021-03-03"}, {}, {}),
            "GetTagBasic": ApiInfo(
                "POST", "/", {"Action": "GetTagBasic", "Version": "2021-03-03"}, {}, {}),
            "GetTagAdditionBasic": ApiInfo(
                "POST", "/", {"Action": "GetTagAdditionBasic", "Version": "2021-03-03"}, {}, {})}

        return api_info

    @ redo.retriable(sleeptime=0.1, jitter=0.01, attempts=2, retry_exceptions=(exceptions.ConnectionError, exceptions.ConnectTimeout))
    def delete_namespace_basic(self, params, body):
        res = self.json("DeleteNamespaceBasic", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    @ redo.retriable(sleeptime=0.1, jitter=0.01, attempts=2, retry_exceptions=(exceptions.ConnectionError, exceptions.ConnectTimeout))
    def create_namespace_basic(self, params, body):
        res = self.json("CreateNamespaceBasic", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    @ redo.retriable(sleeptime=0.1, jitter=0.01, attempts=2, retry_exceptions=(exceptions.ConnectionError, exceptions.ConnectTimeout))
    def validate_namespace_basic(self, params, body):
        res = self.json("ValidateNamespaceBasic", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    @ redo.retriable(sleeptime=0.1, jitter=0.01, attempts=2, retry_exceptions=(exceptions.ConnectionError, exceptions.ConnectTimeout))
    def get_namespace_basic(self, params, body):
        res = self.json("GetNamespaceBasic", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    @ redo.retriable(sleeptime=0.1, jitter=0.01, attempts=2, retry_exceptions=(exceptions.ConnectionError, exceptions.ConnectTimeout))
    def list_namespaces_basic(self, params, body):
        res = self.json("ListNamespacesBasic", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    @ redo.retriable(sleeptime=0.1, jitter=0.01, attempts=2, retry_exceptions=(exceptions.ConnectionError, exceptions.ConnectTimeout))
    def validate_repository_basic(self, params, body):
        res = self.json("ValidateRepositoryBasic", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    @ redo.retriable(sleeptime=0.1, jitter=0.01, attempts=2, retry_exceptions=(exceptions.ConnectionError, exceptions.ConnectTimeout))
    def delete_repository_basic(self, params, body):
        res = self.json("DeleteRepositoryBasic", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    @ redo.retriable(sleeptime=0.1, jitter=0.01, attempts=2, retry_exceptions=(exceptions.ConnectionError, exceptions.ConnectTimeout))
    def create_repository_basic(self, params, body):
        res = self.json("CreateRepositoryBasic", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    @ redo.retriable(sleeptime=0.1, jitter=0.01, attempts=2, retry_exceptions=(exceptions.ConnectionError, exceptions.ConnectTimeout))
    def update_repository_basic(self, params, body):
        res = self.json("UpdateRepositoryBasic", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    @ redo.retriable(sleeptime=0.1, jitter=0.01, attempts=2, retry_exceptions=(exceptions.ConnectionError, exceptions.ConnectTimeout))
    def get_repository_basic(self, params, body):
        res = self.json("GetRepositoryBasic", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    @ redo.retriable(sleeptime=0.1, jitter=0.01, attempts=2, retry_exceptions=(exceptions.ConnectionError, exceptions.ConnectTimeout))
    def list_repositories_basic(self, params, body):
        res = self.json("ListRepositoriesBasic", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    @ redo.retriable(sleeptime=0.1, jitter=0.01, attempts=2, retry_exceptions=(exceptions.ConnectionError, exceptions.ConnectTimeout))
    def delete_tag_basic(self, params, body):
        res = self.json("DeleteTagBasic", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    @ redo.retriable(sleeptime=0.1, jitter=0.01, attempts=2, retry_exceptions=(exceptions.ConnectionError, exceptions.ConnectTimeout))
    def list_tags_basic(self, params, body):
        res = self.json("ListTagsBasic", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    @ redo.retriable(sleeptime=0.1, jitter=0.01, attempts=2, retry_exceptions=(exceptions.ConnectionError, exceptions.ConnectTimeout))
    def get_tag_basic(self, params, body):
        res = self.json("GetTagBasic", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    @ redo.retriable(sleeptime=0.1, jitter=0.01, attempts=2, retry_exceptions=(exceptions.ConnectionError, exceptions.ConnectTimeout))
    def get_tag_addition_basic(self, params, body):
        res = self.json("GetTagAdditionBasic", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json



# coding:utf-8

from volcengine.notify.notify import NotifyService

if __name__ == '__main__':
    notify_service = NotifyService()

    notify_service.set_ak("your ak")
    notify_service.set_sk("your sk")

    body = {
        "Name": "我的tts测试",
        "TtsTemplateContent": "测试文本",
        "Remark": "测试",
        "TtsOption":"{\"loop\":0,\"loop_interval\":0,\"speed\":10,\"volume\":10,\"pitch\":10,\"voice_type\":\"BV001_streaming\",\"lang\":\"ch\",\"voice\":\"other\"}"
    }

    notify_service.create_tts(body)


# coding:utf-8
from volcengine.secretnumber.SecretNumberService import SecretNumberService

if __name__ == '__main__':
    secretNumberService = SecretNumberService()

    secretNumberService.set_ak("")
    secretNumberService.set_sk("")

    unbind_axb_form = {
        "NumberPoolNo": "NP161156328504091435",
        "SubId": "S16328999093159b70bc71",
    }
    print(secretNumberService.unbind_axb(unbind_axb_form))



# coding:utf-8
import json
import threading

from volcengine.ApiInfo import ApiInfo
from volcengine.Credentials import Credentials
from volcengine.base.Service import Service
from volcengine.ServiceInfo import ServiceInfo


class VisualService(Service):
    _instance_lock = threading.Lock()

    def __new__(cls, *args, **kwargs):
        if not hasattr(VisualService, "_instance"):
            with VisualService._instance_lock:
                if not hasattr(VisualService, "_instance"):
                    VisualService._instance = object.__new__(cls)
        return VisualService._instance

    def __init__(self):
        self.service_info = VisualService.get_service_info()
        self.api_info = VisualService.get_api_info()
        super(VisualService, self).__init__(self.service_info, self.api_info)

    @staticmethod
    def get_service_info():
        service_info = ServiceInfo("visual.volcengineapi.com", {},
                                   Credentials('', '', 'cv', 'cn-north-1'), 10, 30)
        return service_info

    @staticmethod
    def get_api_info():
        api_info = {
            "JPCartoonCut": ApiInfo("POST", "/", {"Action": "JPCartoonCut", "Version": "2020-08-26"}, {}, {}),
            "JPCartoon": ApiInfo("POST", "/", {"Action": "JPCartoon", "Version": "2020-08-26"}, {}, {}),
            "IDCard": ApiInfo("POST", "/", {"Action": "IDCard", "Version": "2020-08-26"}, {}, {}),
            "FaceSwap": ApiInfo("POST", "/", {"Action": "FaceSwap", "Version": "2020-08-26"}, {}, {}),
            "OCRNormal": ApiInfo("POST", "/", {"Action": "OCRNormal", "Version": "2020-08-26"}, {}, {}),
            "BankCard": ApiInfo("POST", "/", {"Action": "BankCard", "Version": "2020-08-26"}, {}, {}),
            "HumanSegment": ApiInfo("POST", "/", {"Action": "HumanSegment", "Version": "2020-08-26"}, {}, {}),
            "GeneralSegment": ApiInfo("POST", "/", {"Action": "GeneralSegment", "Version": "2020-08-26"}, {}, {}),
            "EnhancePhoto": ApiInfo("POST", "/", {"Action": "EnhancePhoto", "Version": "2020-08-26"}, {}, {}),
            "ConvertPhoto": ApiInfo("POST", "/", {"Action": "ConvertPhoto", "Version": "2020-08-26"}, {}, {}),
            "VideoSceneDetect": ApiInfo("POST", "/", {"Action": "VideoSceneDetect", "Version": "2020-08-26"}, {}, {}),
            "OverResolution": ApiInfo("POST", "/", {"Action": "OverResolution", "Version": "2020-08-26"}, {}, {}),
            "GoodsSegment": ApiInfo("POST", "/", {"Action": "GoodsSegment", "Version": "2020-08-26"}, {}, {}),
            "ImageOutpaint": ApiInfo("POST", "/", {"Action": "ImageOutpaint", "Version": "2020-08-26"}, {}, {}),
            "ImageInpaint": ApiInfo("POST", "/", {"Action": "ImageInpaint", "Version": "2020-08-26"}, {}, {}),
            "ImageCut": ApiInfo("POST", "/", {"Action": "ImageCut", "Version": "2020-08-26"}, {}, {}),
            "EntityDetect": ApiInfo("POST", "/", {"Action": "EntityDetect", "Version": "2020-08-26"}, {}, {}),
            "GoodsDetect": ApiInfo("POST", "/", {"Action": "GoodsDetect", "Version": "2020-08-26"}, {}, {}),
            "VideoSummarizationSubmitTask": ApiInfo("POST", "/", {"Action": "VideoSummarizationSubmitTask", "Version": "2020-08-26"}, {}, {}),
            "VideoSummarizationQueryTask": ApiInfo("GET", "/", {"Action": "VideoSummarizationQueryTask", "Version": "2020-08-26"}, {}, {}),
            "VideoOverResolutionSubmitTask": ApiInfo("POST", "/", {"Action": "VideoOverResolutionSubmitTask", "Version": "2020-08-26"}, {}, {}),
            "VideoOverResolutionQueryTask": ApiInfo("GET", "/", {"Action": "VideoOverResolutionQueryTask", "Version": "2020-08-26"}, {}, {}),
            "VideoRetargetingSubmitTask": ApiInfo("POST", "/", {"Action": "VideoRetargetingSubmitTask", "Version": "2020-08-26"}, {}, {}),
            "VideoRetargetingQueryTask": ApiInfo("GET", "/", {"Action": "VideoRetargetingQueryTask", "Version": "2020-08-26"}, {}, {}),
            "VideoInpaintSubmitTask": ApiInfo("POST", "/", {"Action": "VideoInpaintSubmitTask", "Version": "2020-08-26"}, {}, {}),
            "VideoInpaintQueryTask": ApiInfo("GET", "/", {"Action": "VideoInpaintQueryTask", "Version": "2020-08-26"}, {}, {}),
            "CarPlateDetection": ApiInfo("POST", "/", {"Action": "CarPlateDetection", "Version": "2020-08-26"}, {}, {}),
            "DistortionFree": ApiInfo("POST", "/", {"Action": "DistortionFree", "Version": "2020-08-26"}, {}, {}),
            "StretchRecovery": ApiInfo("POST", "/", {"Action": "StretchRecovery", "Version": "2020-08-26"}, {}, {}),
            "ImageFlow": ApiInfo("POST", "/", {"Action": "ImageFlow", "Version": "2020-08-26"}, {}, {}),
            "ImageScore": ApiInfo("POST", "/", {"Action": "ImageScore", "Version": "2020-08-26"}, {}, {}),
            "PoemMaterial": ApiInfo("POST", "/", {"Action": "PoemMaterial", "Version": "2020-08-26"}, {}, {}),
            "EmoticonEdit": ApiInfo("POST", "/", {"Action": "EmoticonEdit", "Version": "2020-08-26"}, {}, {}),
            "EyeClose2Open": ApiInfo("POST", "/", {"Action": "EyeClose2Open", "Version": "2020-08-26"}, {}, {}),
            "CarSegment": ApiInfo("POST", "/", {"Action": "CarSegment", "Version": "2020-08-26"}, {}, {}),
            "CarDetection": ApiInfo("POST", "/", {"Action": "CarDetection", "Version": "2020-08-26"}, {}, {}),
            "SkySegment": ApiInfo("POST", "/", {"Action": "SkySegment", "Version": "2020-08-26"}, {}, {}),
            "ImageSearchImageAdd": ApiInfo("POST", "/", {"Action": "ImageSearchImageAdd", "Version": "2020-08-26"}, {}, {}),
            "ImageSearchImageDelete": ApiInfo("POST", "/", {"Action": "ImageSearchImageDelete", "Version": "2020-08-26"}, {}, {}),
            "ImageSearchImageSearch": ApiInfo("POST", "/", {"Action": "ImageSearchImageSearch", "Version": "2020-08-26"}, {}, {}),
            "ClueLicense": ApiInfo("POST", "/", {"Action": "OcrClueLicense", "Version": "2020-08-26"}, {}, {}),
            "DrivingLicense": ApiInfo("POST", "/", {"Action": "DrivingLicense", "Version": "2020-08-26"}, {}, {}),
            "VehicleLicense": ApiInfo("POST", "/", {"Action": "VehicleLicense", "Version": "2020-08-26"}, {}, {}),
            "TaxiInvoice": ApiInfo("POST", "/", {"Action": "OcrTaxiInvoice", "Version": "2020-08-26"}, {}, {}),
            "TrainTicket": ApiInfo("POST", "/", {"Action": "OcrTrainTicket", "Version": "2020-08-26"}, {}, {}),
            "FlightInvoice": ApiInfo("POST", "/", {"Action": "OcrFlightInvoice", "Version": "2020-08-26"}, {}, {}),
            "VatInvoice": ApiInfo("POST", "/", {"Action": "OcrVatInvoice", "Version": "2020-08-26"}, {}, {}),
            "QuotaInvoice": ApiInfo("POST", "/", {"Action": "OcrQuotaInvoice", "Version": "2020-08-26"}, {}, {}),
            "HairStyle": ApiInfo("POST", "/", {"Action": "HairStyle", "Version": "2020-08-26"}, {}, {}),
            "FacePretty": ApiInfo("POST", "/", {"Action": "FacePretty", "Version": "2020-08-26"}, {}, {}),
            "ImageAnimation": ApiInfo("POST", "/", {"Action": "ImageAnimation", "Version": "2020-08-26"}, {}, {}),
            "CoverVideo": ApiInfo("POST", "/", {"Action": "CoverVideo", "Version": "2020-08-26"}, {}, {}),
            "DollyZoom": ApiInfo("POST", "/", {"Action": "DollyZoom", "Version": "2020-08-26"}, {}, {}),
            "PotraitEffect": ApiInfo("POST", "/", {"Action": "PotraitEffect", "Version": "2020-08-26"}, {}, {}),
            "ImageStyleConversion": ApiInfo("POST", "/", {"Action": "ImageStyleConversion", "Version": "2020-08-26"}, {}, {}),
            "3DGameCartoon": ApiInfo("POST", "/", {"Action": "3DGameCartoon", "Version": "2020-08-26"}, {}, {}),
            "HairSegment": ApiInfo("POST", "/", {"Action": "HairSegment", "Version": "2020-08-26"}, {}, {}),
            "OcrSeal": ApiInfo("POST", "/", {"Action": "OcrSeal", "Version": "2021-08-23"}, {}, {}),
            "OcrPassInvoice": ApiInfo("POST", "/", {"Action": "OcrPassInvoice", "Version": "2021-08-23"}, {}, {}),
            "OCRTrade": ApiInfo("POST", "/", {"Action": "OCRTrade", "Version": "2020-12-21"}, {}, {}),
            "OCRRuanzhu": ApiInfo("POST", "/", {"Action": "OCRRuanzhu", "Version": "2020-12-21"}, {}, {}),
            "OCRCosmeticProduct": ApiInfo("POST", "/", {"Action": "OCRCosmeticProduct", "Version": "2020-12-21"}, {}, {}),
            "OCRPdf": ApiInfo("POST", "/", {"Action": "OCRPdf", "Version": "2021-08-23"}, {}, {}),
            "OCRTable": ApiInfo("POST", "/", {"Action": "OCRTable", "Version": "2021-08-23"}, {}, {}),
            "VideoCoverSelection": ApiInfo("POST", "/", {"Action": "VideoCoverSelection", "Version": "2020-08-26"}, {}, {}),
            "VideoHighlightExtractionSubmitTask": ApiInfo("POST", "/", {"Action": "VideoHighlightExtractionSubmitTask", "Version": "2020-08-26"}, {}, {}),
            "VideoHighlightExtractionQueryTask": ApiInfo("GET", "/", {"Action": "VideoHighlightExtractionQueryTask", "Version": "2020-08-26"}, {}, {}),
        }
        return api_info

    def common_handler(self, api, form):
        params = dict()
        try:
            res = self.post(api, params, form)
            res_json = json.loads(res)
            return res_json
        except Exception as e:
            res = str(e)
            try:
                res_json = json.loads(res)
                return res_json
            except:
                raise Exception(str(e))

    def common_get_handler(self, api, params):
        try:
            res = self.get(api, params)
            res_json = json.loads(res)
            return res_json
        except Exception as e:
            res = str(e)
            try:
                res_json = json.loads(res)
                return res_json
            except:
                raise Exception(str(e))

    def jpcartoon_cut(self, form):
        try:
            res_json = self.common_handler("JPCartoonCut", form)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    def jpcartoon(self, form):
        try:
            res_json = self.common_handler("JPCartoon", form)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    def id_card(self, form):
        try:
            res_json = self.common_handler("IDCard", form)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    def face_swap(self, form):
        try:
            res_json = self.common_handler("FaceSwap", form)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    def ocr_normal(self, form):
        try:
            res_json = self.common_handler("OCRNormal", form)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    def bank_card(self, form):
        try:
            res_json = self.common_handler("BankCard", form)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    def human_segment(self, form):
        try:
            res_json = self.common_handler("HumanSegment", form)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    def general_segment(self, form):
        try:
            res_json = self.common_handler("GeneralSegment", form)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    def enhance_photo(self, form):
        try:
            res_json = self.common_handler("EnhancePhoto", form)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    def convert_photo(self, form):
        try:
            res_json = self.common_handler("ConvertPhoto", form)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    def video_scene_detect(self, form):
        try:
            res_json = self.common_handler("VideoSceneDetect", form)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    def over_resolution(self, form):
        try:
            res_json = self.common_handler("OverResolution", form)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    def goods_segment(self, form):
        try:
            res_json = self.common_handler("GoodsSegment", form)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    def image_outpaint(self, form):
        try:
            res_json = self.common_handler("ImageOutpaint", form)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    def image_inpaint(self, form):
        try:
            res_json = self.common_handler("ImageInpaint", form)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    def image_cut(self, form):
        try:
            res_json = self.common_handler("ImageCut", form)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    def entity_detect(self, form):
        try:
            res_json = self.common_handler("EntityDetect", form)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    def goods_detect(self, form):
        try:
            res_json = self.common_handler("GoodsDetect", form)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    def video_summarization_submit_task(self, form):
        try:
            res_json = self.common_handler(
                "VideoSummarizationSubmitTask", form)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    def video_summarization_query_task(self, params):
        try:
            res_json = self.common_get_handler(
                "VideoSummarizationQueryTask", params)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    def video_over_resolution_submit_task(self, form):
        try:
            res_json = self.common_handler(
                "VideoOverResolutionSubmitTask", form)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    def video_over_resolution_query_task(self, params):
        try:
            res_json = self.common_get_handler(
                "VideoOverResolutionQueryTask", params)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    def video_retargeting_submit_task(self, form):
        try:
            res_json = self.common_handler(
                "VideoRetargetingSubmitTask", form)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    def video_retargeting_query_task(self, params):
        try:
            res_json = self.common_get_handler(
                "VideoRetargetingQueryTask", params)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    def video_inpaint_submit_task(self, form):
        try:
            res_json = self.common_handler(
                "VideoInpaintSubmitTask", form)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    def video_inpaint_query_task(self, params):
        try:
            res_json = self.common_get_handler(
                "VideoInpaintQueryTask", params)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    def car_plate_detection(self, form):
        try:
            res_json = self.common_handler("CarPlateDetection", form)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    def distortion_free(self, form):
        try:
            res_json = self.common_handler("DistortionFree", form)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    def stretch_recovery(self, form):
        try:
            res_json = self.common_handler("StretchRecovery", form)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    def image_flow(self, form):
        try:
            res_json = self.common_handler("ImageFlow", form)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    def image_score(self, form):
        try:
            res_json = self.common_handler("ImageScore", form)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    def poem_material(self, form):
        try:
            res_json = self.common_handler("PoemMaterial", form)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    def emoticon_edit(self, form):
        try:
            res_json = self.common_handler("EmoticonEdit", form)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    def eye_close2open(self, form):
        try:
            res_json = self.common_handler("EyeClose2Open", form)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    def car_segment(self, form):
        try:
            res_json = self.common_handler("CarSegment", form)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    def car_detection(self, form):
        try:
            res_json = self.common_handler("CarDetection", form)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    def sky_segment(self, form):
        try:
            res_json = self.common_handler("SkySegment", form)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    def image_search_image_add(self, form):
        try:
            res_json = self.common_handler("ImageSearchImageAdd", form)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    def image_search_image_delete(self, form):
        try:
            res_json = self.common_handler("ImageSearchImageDelete", form)
            return res_json
        except Exception as e:
            raise Exception(str(e))
    
    def image_search_image_search(self, form):
        try:
            res_json = self.common_handler("ImageSearchImageSearch", form)
            return res_json
        except Exception as e:
            raise Exception(str(e))
    
    def clue_license(self, form):
        try:
            res_json = self.common_handler("ClueLicense", form)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    def driving_license(self, form):
        try:
            res_json = self.common_handler("DrivingLicense", form)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    def vehicle_license(self, form):
        try:
            res_json = self.common_handler("VehicleLicense", form)
            return res_json
        except Exception as e:
            raise Exception(str(e))
    
    def taxi_invoice(self, form):
        try:
            res_json = self.common_handler("TaxiInvoice", form)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    def train_ticket(self, form):
        try:
            res_json = self.common_handler("TrainTicket", form)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    def flight_invoice(self, form):
        try:
            res_json = self.common_handler("FlightInvoice", form)
            return res_json
        except Exception as e:
            raise Exception(str(e))
    
    def vat_invoice(self, form):
        try:
            res_json = self.common_handler("VatInvoice", form)
            return res_json
        except Exception as e:
            raise Exception(str(e))
    
    def quota_invoice(self, form):
        try:
            res_json = self.common_handler("QuotaInvoice", form)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    def hair_style(self, form):
        try:
            res_json = self.common_handler("HairStyle", form)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    def face_pretty(self, form):
        try:
            res_json = self.common_handler("FacePretty", form)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    def image_animation(self, form):
        try:
            res_json = self.common_handler("ImageAnimation", form)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    def cover_video(self, form):
        try:
            res_json = self.common_handler("CoverVideo", form)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    def dolly_zoom(self, form):
        try:
            res_json = self.common_handler("DollyZoom", form)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    def potrait_effect(self, form):
        try:
            res_json = self.common_handler("PotraitEffect", form)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    def image_style_conversion(self, form):
        try:
            res_json = self.common_handler("ImageStyleConversion", form)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    def three_d_game_cartoon(self, form):
        try:
            res_json = self.common_handler("3DGameCartoon", form)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    def hair_segment(self, form):
        try:
            res_json = self.common_handler("HairSegment", form)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    def ocr_seal(self, form):
        try:
            res_json = self.common_handler("OcrSeal", form)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    def ocr_pass_invoice(self, form):
        try:
            res_json = self.common_handler("OcrPassInvoice", form)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    def ocr_trade(self, form):
        try:
            res_json = self.common_handler("OCRTrade", form)
            return res_json
        except Exception as e:
            raise Exception(str(e))
    
    def ocr_ruanzhu(self, form):
        try:
            res_json = self.common_handler("OCRRuanzhu", form)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    def ocr_cosmetic_product(self, form):
        try:
            res_json = self.common_handler("OCRCosmeticProduct", form)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    def ocr_pdf(self, form):
        try:
            res_json = self.common_handler("OCRPdf", form)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    def ocr_table(self, form):
        try:
            res_json = self.common_handler("OCRTable", form)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    def video_cover_selection(self, form):
        try:
            res_json = self.common_handler("VideoCoverSelection", form)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    def video_highlight_extraction_submit_task(self, form):
        try:
            res_json = self.common_handler(
                "VideoHighlightExtractionSubmitTask", form)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    def video_highlight_extraction_query_task(self, params):
        try:
            res_json = self.common_get_handler(
                "VideoHighlightExtractionQueryTask", params)
            return res_json
        except Exception as e:
            raise Exception(str(e))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: base/base.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='base/base.proto',
  package='Volcengine.Vod.Models.Base',
  syntax='proto3',
  serialized_options=b'\n%com.volcengine.service.vod.model.baseB\004BaseP\001Z=github.com/volcengine/volc-sdk-golang/service/vod/models/base\240\001\001\330\001\001\302\002\000\312\002\034Volc\\Service\\Vod\\Models\\Base\342\002#Volc\\Service\\Vod\\Models\\GPBMetadata',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0f\x62\x61se/base.proto\x12\x1aVolcengine.Vod.Models.Base\x1a google/protobuf/descriptor.proto\"\xa1\x01\n\x10ResponseMetadata\x12\x11\n\tRequestId\x18\x01 \x01(\t\x12\x0e\n\x06\x41\x63tion\x18\x02 \x01(\t\x12\x0f\n\x07Version\x18\x03 \x01(\t\x12\x0f\n\x07Service\x18\x04 \x01(\t\x12\x0e\n\x06Region\x18\x05 \x01(\t\x12\x38\n\x05\x45rror\x18\x06 \x01(\x0b\x32).Volcengine.Vod.Models.Base.ResponseError\".\n\rResponseError\x12\x0c\n\x04\x43ode\x18\x01 \x01(\t\x12\x0f\n\x07Message\x18\x02 \x01(\tB\xbc\x01\n%com.volcengine.service.vod.model.baseB\x04\x42\x61seP\x01Z=github.com/volcengine/volc-sdk-golang/service/vod/models/base\xa0\x01\x01\xd8\x01\x01\xc2\x02\x00\xca\x02\x1cVolc\\Service\\Vod\\Models\\Base\xe2\x02#Volc\\Service\\Vod\\Models\\GPBMetadatab\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_descriptor__pb2.DESCRIPTOR,])




_RESPONSEMETADATA = _descriptor.Descriptor(
  name='ResponseMetadata',
  full_name='Volcengine.Vod.Models.Base.ResponseMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='RequestId', full_name='Volcengine.Vod.Models.Base.ResponseMetadata.RequestId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Action', full_name='Volcengine.Vod.Models.Base.ResponseMetadata.Action', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Version', full_name='Volcengine.Vod.Models.Base.ResponseMetadata.Version', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Service', full_name='Volcengine.Vod.Models.Base.ResponseMetadata.Service', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Region', full_name='Volcengine.Vod.Models.Base.ResponseMetadata.Region', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Error', full_name='Volcengine.Vod.Models.Base.ResponseMetadata.Error', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=82,
  serialized_end=243,
)


_RESPONSEERROR = _descriptor.Descriptor(
  name='ResponseError',
  full_name='Volcengine.Vod.Models.Base.ResponseError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Code', full_name='Volcengine.Vod.Models.Base.ResponseError.Code', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Message', full_name='Volcengine.Vod.Models.Base.ResponseError.Message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=245,
  serialized_end=291,
)

_RESPONSEMETADATA.fields_by_name['Error'].message_type = _RESPONSEERROR
DESCRIPTOR.message_types_by_name['ResponseMetadata'] = _RESPONSEMETADATA
DESCRIPTOR.message_types_by_name['ResponseError'] = _RESPONSEERROR
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ResponseMetadata = _reflection.GeneratedProtocolMessageType('ResponseMetadata', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSEMETADATA,
  '__module__' : 'base.base_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Base.ResponseMetadata)
  })
_sym_db.RegisterMessage(ResponseMetadata)

ResponseError = _reflection.GeneratedProtocolMessageType('ResponseError', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSEERROR,
  '__module__' : 'base.base_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Base.ResponseError)
  })
_sym_db.RegisterMessage(ResponseError)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# coding:utf-8

from volcengine.notify.notify import NotifyService

if __name__ == '__main__':
    notify_service = NotifyService()

    notify_service.set_ak("your ak")
    notify_service.set_sk("your sk")

    batch_append_task = {
        "TaskOpenId": "106d2984fbf0480480cbc8b98d609592",
        "PhoneList": [
            {
                "Phone": "your phone",
            }
        ],
    }

    print(notify_service.batch_append_task(batch_append_task))



# coding:utf-8
import json

from volcengine.live.LiveService import LiveService

if __name__ == '__main__':
    live_service = LiveService()
    ak = ""
    sk = ""
    live_service.set_ak(ak)
    live_service.set_sk(sk)
    body = {
        "Preset": "preset",
        "Vhost": "vhost",
        "App": "app",
        "Status": 1,
        "Bucket": "bb",
        "RecordTob": [
            {
                "Format": "hls",
                "Duration": 100,
                "Splice": -1,
                "RecordObject": "/xx/xx",
            },
        ],
    }
    resp = live_service.update_record_preset(body)
    print(resp)



# coding:utf-8
import json

from volcengine.live.LiveService import LiveService

if __name__ == '__main__':
    live_service = LiveService()
    ak = ""
    sk = ""
    live_service.set_ak(ak)
    live_service.set_sk(sk)
    body = {
        # "Domain": "push-rtmp-testpython.xxx.xx",
        "Domain": "pull-rtmp-testpython.xxx.xx",
        # "Type": "push",
        "Type": "pull-flv",
    }
    resp = live_service.create_domain(body)
    print(resp)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: imp/response/response_imp.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from volcengine.imp.models.base import base_pb2 as base_dot_base__pb2
from volcengine.imp.models.business import imp_common_pb2 as imp_dot_business_dot_imp__common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='imp/response/response_imp.proto',
  package='Volcengine.Imp.Models.Response',
  syntax='proto3',
  serialized_options=b'\n)com.volcengine.service.imp.model.responseB\013ImpResponseP\001ZAgithub.com/volcengine/volc-sdk-golang/service/imp/models/response\240\001\001\330\001\001\312\002 Volc\\Service\\Imp\\Models\\Response\342\002#Volc\\Service\\Imp\\Models\\GPBMetadata',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1fimp/response/response_imp.proto\x12\x1eVolcengine.Imp.Models.Response\x1a\x0f\x62\x61se/base.proto\x1a\x1dimp/business/imp_common.proto\"n\n\x14ImpSubmitJobResponse\x12\x46\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32,.Volcengine.Vod.Models.Base.ResponseMetadata\x12\x0e\n\x06Result\x18\x02 \x01(\t\"\\\n\x12ImpKillJobResponse\x12\x46\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32,.Volcengine.Vod.Models.Base.ResponseMetadata\"\x91\x02\n\x16ImpRetrieveJobResponse\x12\x46\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32,.Volcengine.Vod.Models.Base.ResponseMetadata\x12R\n\x06Result\x18\x02 \x03(\x0b\x32\x42.Volcengine.Imp.Models.Response.ImpRetrieveJobResponse.ResultEntry\x1a[\n\x0bResultEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12;\n\x05value\x18\x02 \x01(\x0b\x32,.Volcengine.Imp.Models.Business.JobExecution:\x02\x38\x01\x42\xcc\x01\n)com.volcengine.service.imp.model.responseB\x0bImpResponseP\x01ZAgithub.com/volcengine/volc-sdk-golang/service/imp/models/response\xa0\x01\x01\xd8\x01\x01\xca\x02 Volc\\Service\\Imp\\Models\\Response\xe2\x02#Volc\\Service\\Imp\\Models\\GPBMetadatab\x06proto3'
  ,
  dependencies=[base_dot_base__pb2.DESCRIPTOR,imp_dot_business_dot_imp__common__pb2.DESCRIPTOR,])




_IMPSUBMITJOBRESPONSE = _descriptor.Descriptor(
  name='ImpSubmitJobResponse',
  full_name='Volcengine.Imp.Models.Response.ImpSubmitJobResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ResponseMetadata', full_name='Volcengine.Imp.Models.Response.ImpSubmitJobResponse.ResponseMetadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Result', full_name='Volcengine.Imp.Models.Response.ImpSubmitJobResponse.Result', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=115,
  serialized_end=225,
)


_IMPKILLJOBRESPONSE = _descriptor.Descriptor(
  name='ImpKillJobResponse',
  full_name='Volcengine.Imp.Models.Response.ImpKillJobResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ResponseMetadata', full_name='Volcengine.Imp.Models.Response.ImpKillJobResponse.ResponseMetadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=227,
  serialized_end=319,
)


_IMPRETRIEVEJOBRESPONSE_RESULTENTRY = _descriptor.Descriptor(
  name='ResultEntry',
  full_name='Volcengine.Imp.Models.Response.ImpRetrieveJobResponse.ResultEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Volcengine.Imp.Models.Response.ImpRetrieveJobResponse.ResultEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='Volcengine.Imp.Models.Response.ImpRetrieveJobResponse.ResultEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=504,
  serialized_end=595,
)

_IMPRETRIEVEJOBRESPONSE = _descriptor.Descriptor(
  name='ImpRetrieveJobResponse',
  full_name='Volcengine.Imp.Models.Response.ImpRetrieveJobResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ResponseMetadata', full_name='Volcengine.Imp.Models.Response.ImpRetrieveJobResponse.ResponseMetadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Result', full_name='Volcengine.Imp.Models.Response.ImpRetrieveJobResponse.Result', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_IMPRETRIEVEJOBRESPONSE_RESULTENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=322,
  serialized_end=595,
)

_IMPSUBMITJOBRESPONSE.fields_by_name['ResponseMetadata'].message_type = base_dot_base__pb2._RESPONSEMETADATA
_IMPKILLJOBRESPONSE.fields_by_name['ResponseMetadata'].message_type = base_dot_base__pb2._RESPONSEMETADATA
_IMPRETRIEVEJOBRESPONSE_RESULTENTRY.fields_by_name['value'].message_type = imp_dot_business_dot_imp__common__pb2._JOBEXECUTION
_IMPRETRIEVEJOBRESPONSE_RESULTENTRY.containing_type = _IMPRETRIEVEJOBRESPONSE
_IMPRETRIEVEJOBRESPONSE.fields_by_name['ResponseMetadata'].message_type = base_dot_base__pb2._RESPONSEMETADATA
_IMPRETRIEVEJOBRESPONSE.fields_by_name['Result'].message_type = _IMPRETRIEVEJOBRESPONSE_RESULTENTRY
DESCRIPTOR.message_types_by_name['ImpSubmitJobResponse'] = _IMPSUBMITJOBRESPONSE
DESCRIPTOR.message_types_by_name['ImpKillJobResponse'] = _IMPKILLJOBRESPONSE
DESCRIPTOR.message_types_by_name['ImpRetrieveJobResponse'] = _IMPRETRIEVEJOBRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ImpSubmitJobResponse = _reflection.GeneratedProtocolMessageType('ImpSubmitJobResponse', (_message.Message,), {
  'DESCRIPTOR' : _IMPSUBMITJOBRESPONSE,
  '__module__' : 'imp.response.response_imp_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Imp.Models.Response.ImpSubmitJobResponse)
  })
_sym_db.RegisterMessage(ImpSubmitJobResponse)

ImpKillJobResponse = _reflection.GeneratedProtocolMessageType('ImpKillJobResponse', (_message.Message,), {
  'DESCRIPTOR' : _IMPKILLJOBRESPONSE,
  '__module__' : 'imp.response.response_imp_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Imp.Models.Response.ImpKillJobResponse)
  })
_sym_db.RegisterMessage(ImpKillJobResponse)

ImpRetrieveJobResponse = _reflection.GeneratedProtocolMessageType('ImpRetrieveJobResponse', (_message.Message,), {

  'ResultEntry' : _reflection.GeneratedProtocolMessageType('ResultEntry', (_message.Message,), {
    'DESCRIPTOR' : _IMPRETRIEVEJOBRESPONSE_RESULTENTRY,
    '__module__' : 'imp.response.response_imp_pb2'
    # @@protoc_insertion_point(class_scope:Volcengine.Imp.Models.Response.ImpRetrieveJobResponse.ResultEntry)
    })
  ,
  'DESCRIPTOR' : _IMPRETRIEVEJOBRESPONSE,
  '__module__' : 'imp.response.response_imp_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Imp.Models.Response.ImpRetrieveJobResponse)
  })
_sym_db.RegisterMessage(ImpRetrieveJobResponse)
_sym_db.RegisterMessage(ImpRetrieveJobResponse.ResultEntry)


DESCRIPTOR._options = None
_IMPRETRIEVEJOBRESPONSE_RESULTENTRY._options = None
# @@protoc_insertion_point(module_scope)



#  -*- coding: utf-8 -*-
import datetime

from volcengine.example.cdn import ak, sk
from volcengine.cdn.service import CDNService

if __name__ == '__main__':
    svc = CDNService()
    svc.set_ak(ak)
    svc.set_sk(sk)

    body = {
        'Domain': 'example.com'
    }

    resp = svc.describe_cdn_config(body)
    print(resp)



import json
import threading
import redo

from volcengine.ApiInfo import ApiInfo
from volcengine.Credentials import Credentials
from volcengine.base.Service import Service
from volcengine.ServiceInfo import ServiceInfo
from requests import exceptions


class CodePipelineService(Service):
    _instance_lock = threading.Lock()

    def __new__(cls, *args, **kwargs):
        if not hasattr(CodePipelineService, "_instance"):
            with CodePipelineService._instance_lock:
                if not hasattr(CodePipelineService, "_instance"):
                    CodePipelineService._instance = object.__new__(cls)
        return CodePipelineService._instance

    def __init__(self):
        self.service_info = CodePipelineService.get_service_info()
        self.api_info = CodePipelineService.get_api_info()
        super(CodePipelineService, self).__init__(
            self.service_info, self.api_info)

    @staticmethod
    def get_service_info():
        service_info = ServiceInfo("open.volcengineapi.com", {'Accept': 'application/json'},
                                   Credentials('', '', 'cp', 'cn-north-1'), 5, 5)
        return service_info

    @staticmethod
    def get_api_info():
        api_info = {
            "UpdateWorkspace": ApiInfo(
                "POST", "/", {"Action": "UpdateWorkspace", "Version": "2021-03-03"}, {}, {}),
            "DeleteWorkspace": ApiInfo(
                "POST", "/", {"Action": "DeleteWorkspace", "Version": "2021-03-03"}, {}, {}),
            "GetWorkspace": ApiInfo(
                "POST", "/", {"Action": "GetWorkspace", "Version": "2021-03-03"}, {}, {}),
            "CreateWorkspace": ApiInfo(
                "POST", "/", {"Action": "CreateWorkspace", "Version": "2021-03-03"}, {}, {}),
            "ListWorkspaces": ApiInfo(
                "POST", "/", {"Action": "ListWorkspaces", "Version": "2021-03-03"}, {}, {}),
            "CopyWorkspace": ApiInfo(
                "POST", "/", {"Action": "CopyWorkspace", "Version": "2021-03-03"}, {}, {}),
            "CreatePipeline": ApiInfo(
                "POST", "/", {"Action": "CreatePipeline", "Version": "2021-03-03"}, {}, {}),
            "ListPipelines": ApiInfo(
                "POST", "/", {"Action": "ListPipelines", "Version": "2021-03-03"}, {}, {}),
            "DeletePipeline": ApiInfo(
                "POST", "/", {"Action": "DeletePipeline", "Version": "2021-03-03"}, {}, {}),
            "UpdatePipeline": ApiInfo(
                "POST", "/", {"Action": "UpdatePipeline", "Version": "2021-03-03"}, {}, {}),
            "GetPipeline": ApiInfo(
                "POST", "/", {"Action": "GetPipeline", "Version": "2021-03-03"}, {}, {}),
            "UpdatePipelineProperties": ApiInfo(
                "POST", "/", {"Action": "UpdatePipelineProperties", "Version": "2021-03-03"}, {}, {}),
            "GetPipelineHookUrl": ApiInfo(
                "POST", "/", {"Action": "GetPipelineHookUrl", "Version": "2021-03-03"}, {}, {}),
            "RunPipeline": ApiInfo(
                "POST", "/", {"Action": "RunPipeline", "Version": "2021-03-03"}, {}, {}),
            "RunRollingUpdate": ApiInfo(
                "POST", "/", {"Action": "RunRollingUpdate", "Version": "2021-03-03"}, {}, {}),
            "DeletePipelineCache": ApiInfo(
                "POST", "/", {"Action": "DeletePipelineCache", "Version": "2021-03-03"}, {}, {}),
            "ListPipelineRecords": ApiInfo(
                "POST", "/", {"Action": "ListPipelineRecords", "Version": "2021-03-03"}, {}, {}),
            "GetPipelineRecord": ApiInfo(
                "POST", "/", {"Action": "GetPipelineRecord", "Version": "2021-03-03"}, {}, {}),
            "StopPipelineRecord": ApiInfo(
                "POST", "/", {"Action": "StopPipelineRecord", "Version": "2021-03-03"}, {}, {}),
            "RetryPipelineRecord": ApiInfo(
                "POST", "/", {"Action": "RetryPipelineRecord", "Version": "2021-03-03"}, {}, {}),
            "DeletePipelineRecord": ApiInfo(
                "POST", "/", {"Action": "DeletePipelineRecord", "Version": "2021-03-03"}, {}, {}),
            "ListPipelineTemplates": ApiInfo(
                "POST", "/", {"Action": "ListPipelineTemplates", "Version": "2021-03-03"}, {}, {}),
            "GetPipelineTemplate": ApiInfo(
                "POST", "/", {"Action": "GetPipelineTemplate", "Version": "2021-03-03"}, {}, {})}

        return api_info

    @ redo.retriable(sleeptime=0.1, jitter=0.01, attempts=2, retry_exceptions=(exceptions.ConnectionError, exceptions.ConnectTimeout))
    def update_workspace(self, params, body):
        res = self.json("UpdateWorkspace", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    @ redo.retriable(sleeptime=0.1, jitter=0.01, attempts=2, retry_exceptions=(exceptions.ConnectionError, exceptions.ConnectTimeout))
    def delete_workspace(self, params, body):
        res = self.json("DeleteWorkspace", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    @ redo.retriable(sleeptime=0.1, jitter=0.01, attempts=2, retry_exceptions=(exceptions.ConnectionError, exceptions.ConnectTimeout))
    def get_workspace(self, params, body):
        res = self.json("GetWorkspace", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    @ redo.retriable(sleeptime=0.1, jitter=0.01, attempts=2, retry_exceptions=(exceptions.ConnectionError, exceptions.ConnectTimeout))
    def create_workspace(self, params, body):
        res = self.json("CreateWorkspace", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    @ redo.retriable(sleeptime=0.1, jitter=0.01, attempts=2, retry_exceptions=(exceptions.ConnectionError, exceptions.ConnectTimeout))
    def list_workspaces(self, params, body):
        res = self.json("ListWorkspaces", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    @ redo.retriable(sleeptime=0.1, jitter=0.01, attempts=2, retry_exceptions=(exceptions.ConnectionError, exceptions.ConnectTimeout))
    def copy_workspace(self, params, body):
        res = self.json("CopyWorkspace", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    @ redo.retriable(sleeptime=0.1, jitter=0.01, attempts=2, retry_exceptions=(exceptions.ConnectionError, exceptions.ConnectTimeout))
    def create_pipeline(self, params, body):
        res = self.json("CreatePipeline", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    @ redo.retriable(sleeptime=0.1, jitter=0.01, attempts=2, retry_exceptions=(exceptions.ConnectionError, exceptions.ConnectTimeout))
    def list_pipelines(self, params, body):
        res = self.json("ListPipelines", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    @ redo.retriable(sleeptime=0.1, jitter=0.01, attempts=2, retry_exceptions=(exceptions.ConnectionError, exceptions.ConnectTimeout))
    def delete_pipeline(self, params, body):
        res = self.json("DeletePipeline", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    @ redo.retriable(sleeptime=0.1, jitter=0.01, attempts=2, retry_exceptions=(exceptions.ConnectionError, exceptions.ConnectTimeout))
    def update_pipeline(self, params, body):
        res = self.json("UpdatePipeline", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    @ redo.retriable(sleeptime=0.1, jitter=0.01, attempts=2, retry_exceptions=(exceptions.ConnectionError, exceptions.ConnectTimeout))
    def get_pipeline(self, params, body):
        res = self.json("GetPipeline", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    @ redo.retriable(sleeptime=0.1, jitter=0.01, attempts=2, retry_exceptions=(exceptions.ConnectionError, exceptions.ConnectTimeout))
    def update_pipeline_properties(self, params, body):
        res = self.json("UpdatePipelineProperties", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    @ redo.retriable(sleeptime=0.1, jitter=0.01, attempts=2, retry_exceptions=(exceptions.ConnectionError, exceptions.ConnectTimeout))
    def get_pipeline_hook_url(self, params, body):
        res = self.json("GetPipelineHookUrl", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    @ redo.retriable(sleeptime=0.1, jitter=0.01, attempts=2, retry_exceptions=(exceptions.ConnectionError, exceptions.ConnectTimeout))
    def run_pipeline(self, params, body):
        res = self.json("RunPipeline", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    @ redo.retriable(sleeptime=0.1, jitter=0.01, attempts=2, retry_exceptions=(exceptions.ConnectionError, exceptions.ConnectTimeout))
    def run_rolling_update(self, params, body):
        res = self.json("RunRollingUpdate", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    @ redo.retriable(sleeptime=0.1, jitter=0.01, attempts=2, retry_exceptions=(exceptions.ConnectionError, exceptions.ConnectTimeout))
    def delete_pipeline_cache(self, params, body):
        res = self.json("DeletePipelineCache", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    @ redo.retriable(sleeptime=0.1, jitter=0.01, attempts=2, retry_exceptions=(exceptions.ConnectionError, exceptions.ConnectTimeout))
    def list_pipeline_records(self, params, body):
        res = self.json("ListPipelineRecords", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    @ redo.retriable(sleeptime=0.1, jitter=0.01, attempts=2, retry_exceptions=(exceptions.ConnectionError, exceptions.ConnectTimeout))
    def get_pipeline_record(self, params, body):
        res = self.json("GetPipelineRecord", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    @ redo.retriable(sleeptime=0.1, jitter=0.01, attempts=2, retry_exceptions=(exceptions.ConnectionError, exceptions.ConnectTimeout))
    def stop_pipeline_record(self, params, body):
        res = self.json("StopPipelineRecord", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    @ redo.retriable(sleeptime=0.1, jitter=0.01, attempts=2, retry_exceptions=(exceptions.ConnectionError, exceptions.ConnectTimeout))
    def retry_pipeline_record(self, params, body):
        res = self.json("RetryPipelineRecord", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    @ redo.retriable(sleeptime=0.1, jitter=0.01, attempts=2, retry_exceptions=(exceptions.ConnectionError, exceptions.ConnectTimeout))
    def delete_pipeline_record(self, params, body):
        res = self.json("DeletePipelineRecord", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    @ redo.retriable(sleeptime=0.1, jitter=0.01, attempts=2, retry_exceptions=(exceptions.ConnectionError, exceptions.ConnectTimeout))
    def list_pipeline_templates(self, params, body):
        res = self.json("ListPipelineTemplates", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    @ redo.retriable(sleeptime=0.1, jitter=0.01, attempts=2, retry_exceptions=(exceptions.ConnectionError, exceptions.ConnectTimeout))
    def get_pipeline_template(self, params, body):
        res = self.json("GetPipelineTemplate", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json
